"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const TempObject = function (ttl = 24 * 60 * 60 * 1000, io) {
    const initialObject = { ...io };
    let expiry;
    function setTimer(key) {
        if (expiry) {
            clearTimeout(expiry[key]);
        }
        return setTimeout(() => {
            delete initialObject[key];
            delete expiry[key];
        }, ttl);
    }
    expiry = Object.keys(initialObject).reduce((obj, key) => {
        obj[key] = setTimer(key);
        return obj;
    }, {});
    return new Proxy(initialObject, {
        get(target, key) {
            const k = key;
            if (Object.keys(target).includes(k)) {
                expiry[k] = setTimer(k);
            }
            return target[k];
        },
        set(target, key, value) {
            const k = key;
            target[k] = value;
            expiry[k] = setTimer(k);
            return true;
        },
    });
};
exports.default = TempObject;
if (typeof exports.default === 'function') {
    module.exports = exports.default;
    Object.assign(module.exports, exports);
}
